@@ -301,8 +301,8 @@ void Manager::load(const TQString &filename)
 pwd_entry:
     int saveToWallet = 1;
 
-    TQCString p_pass(KFTPAPI::getInstance()->walletConnection()->getPassword("bookmarkDecryptPwd").ascii());
-    if (TQString(p_pass).isNull()) {
+    TQString p_pass(KFTPAPI::getInstance()->walletConnection()->getPassword("bookmarkDecryptPwd"));
+    if (p_pass.isNull()) {
       // Ask the user for a password
       int ret = KPasswordDialog::getPassword(p_pass, i18n("This bookmark file is encrypted. Please enter key for decryption."), &saveToWallet);
 
@@ -717,7 +717,7 @@ void Manager::setupClient(Site *site, KFTPEngine::Thread *client)
     // Should we use a X509 certificate ?
     if (site->getIntProperty("use_cert") && site->getProperty("protocol") == "ftp") {
       // Ask the user for the decryption password
-      TQCString certPass;
+      TQString certPass;
       KPasswordDialog::getPassword(certPass, i18n("Please provide your X509 certificate decryption password."));
 
       static_cast<KFTPEngine::FtpSocket*>(client->socket())->setSslClientCertificate(KSSLPKCS12::loadCertFile(site->getProperty("tls_cert_path"), certPass));
