@@ -57,7 +57,7 @@ class TreeViewItem;
  */
 class TreeView : public TDEListView
 {
-Q_OBJECT
+TQ_OBJECT
 friend class ListView;
 friend class TreeViewItem;
 public:
